/*
 * Copyright (C) 2016 Moritz Orbach <zufall@apfelboymchen.net>
 *
 * Zufall is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Zufall is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * multiple monitors via Xinerama
 */
#include <X11/Xutil.h>
#include <X11/extensions/Xinerama.h>
#include "memman.h"
#include "display-x11-xinerama.h"

/*
 * Interface
 */

head_t *xinerama_init(Display *display, int scrnum, Screen *scr, int *headcount)
{
	XineramaScreenInfo *info = NULL;
	int xinerama_heads;
	int infoslots = 0;
	head_t *heads;

	if (XineramaIsActive(display)) {
		info = XineramaQueryScreens(display, &xinerama_heads);
		*headcount = xinerama_heads;
		infoslots = *headcount + 1;
	} else {
		*headcount = xinerama_heads = 1;
		infoslots = 2;
	}
	heads = getmem(sizeof(head_t) * infoslots);
	/* first slot contains info for the complete surface */
	heads[0].offset_x = 0;
	heads[0].offset_y = 0;
	heads[0].width    = scr->width;
	heads[0].height   = scr->height;

	if (info != NULL) {
		int i;
		for (i = 0; i < *headcount; i++) {
			heads[i+1].offset_x = info[i].x_org;
			heads[i+1].offset_y = info[i].y_org;
			heads[i+1].width    = info[i].width;
			heads[i+1].height   = info[i].height;
		}
		//printf("head %d: %dx%d\n", i-1, info[i].width, info[i].height); // debug
		XFree(info);
	} else {
		/* screen 1 (the only screen) is the same size as the whole area */
		heads[1].offset_x = heads[0].offset_x;
		heads[1].offset_y = heads[0].offset_y;
		heads[1].width    = heads[0].width;
		heads[1].height   = heads[0].height;
	}

	return heads;
}

head_t *xinerama_update(Display *display, int scrnum, Screen *scr, int *headcount, XEvent *ev)
{
	return xinerama_init(display, scrnum, scr, headcount);
}
