/*
 * Copyright (C) 2016 Moritz Orbach <zufall@apfelboymchen.net>
 *
 * Zufall is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Zufall is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdarg.h>

#include "../config.h"
#include "memman.h"

void printerrno(char const * const item)
{
	fprintf(stderr, "%s: %s: %s\n", PACKAGE, item, strerror(errno));
}

/*
 * set command->errorstr via format string
 * from man snprintf (on GNU/Linux)
 *
 * *dst may be NULL, but can't point to the stack!
 */
void errorstr(char **dst, const char *fmt, ...)
{
	int size = 0;
	va_list ap;

	if (*dst != NULL)
		free(*dst);

	/* Determine required size */
	va_start(ap, fmt);
	size = vsnprintf(*dst, size, fmt, ap);
	va_end(ap);

	if (size < 0)
		exit(3);

	size++; /* For '\0' */
	*dst = getmem(size);

	va_start(ap, fmt);
	size = vsnprintf(*dst, size, fmt, ap);
	if (size < 0) {
		printerrno("creating an error message");
		free(*dst);
		exit(3);
	}
	va_end(ap);
}
