/*
 * Copyright (C) 2008, 2009, 2106 Moritz Orbach <zufall@apfelboymchen.net>
 *
 * Zufall is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Zufall is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * Fake imglib that does nothing (except printfs). Useful for testing and 
 * demonstrates the interface.
 */
#include <stdio.h>

#include "../src/imglib-display-x11.h"
#include "../src/memman.h"

typedef struct imglib_s {
	int img_loaded;
} imglib_t;


/*
 * interface
 */

void imglib_get_dimensions(int *w, int *h)
{
	*w = 500;
	*h = 500;
}

void imglib_get_color(int x, int y, int *r, int *g, int *b)
{
	*r = 128;
	*g = 128;
	*b = 128;
}

/* load and set current image to imgpath */
int imglib_load(imglib_t *imglib, const char *imgpath)
{
	if (imglib->img_loaded)
		imglib_unload(imglib);

	imglib->img_loaded = 1;
	printf("imglib: loaded %s\n", imgpath);
	return 1;
}

int imglib_unload(imglib_t *imglib)
{
	if (imglib->img_loaded)
		printf("imglib: unloaded current picture\n");
	else
		fprintf(stderr, "imglib: WARN: no picture to unload\n");
	imglib->img_loaded = 0;
	return 1;
}

/* render a scaled version of the current image into pixmap_return */
Pixmap *imglib_render(imglib_t *imglib, int w, int h)
{
	if (!imglib->img_loaded)
		fprintf(stderr, "imglib: ERROR: no image loaded!\n");
	printf("imglib: current picture rendered at %dx%d\n", w, h);
	return None;
}

int imglib_displaysetup(imglib_t *imglib, Display *dsp, Window targetwin)
{
	printf("imglib: set up\n");
	return 1;
}

imglib_t *imglib_init(void)
{
	imglib_t *imglib;
	imglib = getmem(sizeof(imglib_t));
	imglib->img_loaded = 0;

	printf("imglib: initialized\n");

	return imglib;
}

void imglib_destroy(imglib_t *imglib)
{
	if (imglib == NULL)
		return;

	printf("imglib: destroyed\n");

	freemem(imglib);
}

